==> celum_connect-8.x-1.37.tar.gz: celum_connect/src/Plugin/Field/FieldFormatter/CelumConnectFormatter.php <==
<?php

namespace Drupal\celum_connect\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Url;

/**
 * Plugin implementation of the 'celum_connect' formatter.
 *
 * @FieldFormatter(
 *   id = "celum_connect_formatter",
 *   label = @Translation("Celum:connect default"),
 *   field_types = {
 *     "celum_connect_field"
 *   }
 * )
 */
class CelumConnectFormatter extends FormatterBase
{
    /**
     * {@inheritdoc}
     */
    public function viewElements(FieldItemListInterface $items, $langcode) {
        $config = \Drupal::service('config.factory')->getEditable('celum_connect.settings');
        $elements = array();
        foreach ($items as $delta => $item) {
            $element = array(
                '#theme' => 'celum_connect',
                '#fileCategory' => $item->fileCategory,
                '#title' => $item->title ? $item->title : 'Asset '.$item->id,
                '#version' => $item->version,
                '#id' => $item->id,
                '#downloadFormat' => $item->downloadFormat,
                '#fileExtension' => $item->fileExtension,
                '#uri' => file_create_url($item->uri),
                '#thumb' => file_create_url($item->thumb),

            );
            if($config->get('celum_connect_anura_links')) {
                list($url, $t) = explode("_", $this->decrypt($config->get('celum_connect_licenseKey')));
                $element['#fileCategory'] = "anura";
                $element['#uri'] = $url.'/'.$config->get('celum_connect_anura_dispatcher');
            }
            $element['#attached']['library'][] = 'celum_connect/celum-connect-renderer';
            $elements[$delta] = $element;
        }

        return $elements;
    }

    function decrypt($sData){
        $secretKey = "ZbMchtd9DivzjPDi5QIio1iVERFnNZiSE33QKY3Gw9rYfCNLFiKloJQt3zi4";
        $sResult = '';
        $sData   = $this->decode_base64($sData);
        for($i=0;$i<strlen($sData);$i++){
            $sChar    = substr($sData, $i, 1);
            $sKeyChar = substr($secretKey, ($i % strlen($secretKey)) - 1, 1);
            $sChar    = chr(ord($sChar) - ord($sKeyChar));
            $sResult .= $sChar;
        }
        return $sResult;
    }

    function decode_base64($sData){
        $sBase64 = strtr($sData, '-_', '+/');
        return base64_decode($sBase64.'==');
    }

}

==> celum_connect-8.x-1.39.tar.gz: celum_connect/src/Plugin/Field/FieldFormatter/CelumConnectFormatter.php <==
<?php

namespace Drupal\celum_connect\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Url;

/**
 * Plugin implementation of the 'celum_connect' formatter.
 *
 * @FieldFormatter(
 *   id = "celum_connect_formatter",
 *   label = @Translation("Celum:connect default"),
 *   field_types = {
 *     "celum_connect_field"
 *   }
 * )
 */
class CelumConnectFormatter extends FormatterBase
{
    /**
     * {@inheritdoc}
     */
    public function viewElements(FieldItemListInterface $items, $langcode) {
        $config = \Drupal::service('config.factory')->getEditable('celum_connect.settings');
        $elements = array();
        foreach ($items as $delta => $item) {
            $element = array(
                '#theme' => 'celum_connect',
                '#fileCategory' => $item->fileCategory,
                '#title' => $item->title ? $item->title : 'Asset '.$item->id,
                '#version' => $item->version,
                '#id' => $item->id,
                '#downloadFormat' => $item->downloadFormat,
                '#fileExtension' => $item->fileExtension,
                '#uri' => file_create_url($item->uri),
                '#thumb' => file_create_url($item->thumb),

            );
            if($config->get('celum_connect_anura_links')) {
                list($url, $t) = explode("_", $this->decrypt($config->get('celum_connect_licenseKey')));
                $element['#fileCategory'] = "anura";
                if($config->get('celum_connect_anura_urlDispatcherMap')) {
                    $url_dispatcher_array = explode(';', $config->get('celum_connect_anura_urlDispatcherMap'));
                    $foundDispatcher = false;
                    foreach ($url_dispatcher_array as $url_dispatcher) {
                        $url_dispatcher_string_array = explode('>', $url_dispatcher);
                        if(\Drupal::request()->getSchemeAndHttpHost() == $url_dispatcher_string_array[0]) {
                            $element['#uri'] = $url.'/anura/'.$url_dispatcher_string_array[1];
                            $foundDispatcher = true;
                            break;
                        }
                    }
                    if(!$foundDispatcher) {
                        $element['#uri'] = $url.'/anura/'.$config->get('celum_connect_anura_dispatcher');
                    }
                } else {
                    $element['#uri'] = $url.'/anura/'.$config->get('celum_connect_anura_dispatcher');
                }
            }
            $element['#attached']['library'][] = 'celum_connect/celum-connect-renderer';
            $elements[$delta] = $element;
        }

        return $elements;
    }

    function decrypt($sData){
        $secretKey = "ZbMchtd9DivzjPDi5QIio1iVERFnNZiSE33QKY3Gw9rYfCNLFiKloJQt3zi4";
        $sResult = '';
        $sData   = $this->decode_base64($sData);
        for($i=0;$i<strlen($sData);$i++){
            $sChar    = substr($sData, $i, 1);
            $sKeyChar = substr($secretKey, ($i % strlen($secretKey)) - 1, 1);
            $sChar    = chr(ord($sChar) - ord($sKeyChar));
            $sResult .= $sChar;
        }
        return $sResult;
    }

    function decode_base64($sData){
        $sBase64 = strtr($sData, '-_', '+/');
        return base64_decode($sBase64.'==');
    }

}
